@@ -2,6 +2,8 @@ class ExceptionCode:
     InvalidApiKey = 'invalid_api_key'
     PermissionDenied = 'permission_denied'
     InvalidParameters = 'invalid_parameters'
+    NotFound = 'not_found'
+    Other = 'other'
 
 
 class RocketReachException(Exception):
